@@ -2,20 +2,31 @@ art = {}
 
 art.video_suffixes = ['mp4']
 art.img_suffixes = ['jpg', 'png', 'jpeg', 'gif']
-art.audio_suffixes = ['flac', 'mp3', 'ogg']
+art.audio_suffixes = ['flac', 'mp3', 'ogg', 'aac']
 art.pdf_suffixes = ['pdf']
 
-sfetch_json = (url) => {
-    const xhr = new XMLHttpRequest()
-    xhr.open('GET', url, false)
-    xhr.send()
-    return JSON.parse(xhr.responseText)
+let load_yaml = (text) => {
+    return jsyaml.load(text)
 }
 
-sfetch_file_uris = (config_url) => {
-    return sfetch_json(config_url)['file_uris']
+sfetch = (url) => {
+    let xhr = new XMLHttpRequest()
+    xhr.open('GET', url, false)
+    xhr.send()
+    return xhr.responseText
 }
 
+{
+    let meta = null
+    window.get_file_uris = (key) => {
+        if (!meta) {
+            meta = load_yaml(sfetch('art.yaml'))
+        }
+        return meta['file_uris'][key]
+    }
+}
+
+
 sleepm = (milliseconds) => new Promise(resolve => setTimeout(resolve, milliseconds))
 
 art.content_ele = null
@@ -95,6 +106,25 @@ code = (code_string, min_height = 17.5) => {
 }
 art.unfold_code = (textarea) => { textarea.style.height = textarea.scrollHeight + 25 + 'px' }
 
+art.render_s = () => {
+    document.querySelector('text').addEventListener('click', async (event) => {
+        event.preventDefault()
+        let target = event.target
+        let href = target.href || target.getAttribute('href')
+        if (href) {
+            window.open(href, '_blank')
+        }
+        else if (window.frameElement) {
+            if (aim_url) {
+                window.open(aim_url, '_blank')
+            }
+            else {
+                window.open(document.URL, '_blank')
+            }
+        }
+    })
+}
+
 art.render = (mini_title = false, big_title = true, home_link = true) => {
     if (art.content_ele) {
         if (art.src_count === 1) {
@@ -122,8 +152,8 @@ art.render = (mini_title = false, big_title = true, home_link = true) => {
     let title = document.title
     if (window.self === window.top) {
         if (title && mini_title) { mini_title_text = `<mini_title>${title}</mini_title>` }
-        if (title && big_title) { big_title_text = `<h1>${title}</h1>` }
-        if (home_link) { foot_text = `<home_link><button href='/'>主页 👈</button></home_link>` }
+        if (title && big_title) { big_title_text = `<ct1>${title}</ct1>` }
+        if (home_link) { foot_text = `<home_link><button href='/'>灵火与机器 👈</button></home_link>` }
     }
     innerHTML = art.clean_text(mini_title_text + big_title_text + innerHTML + foot_text)
     for (let [k, v] of Object.entries(art.codes)) {
@@ -135,32 +165,13 @@ art.render = (mini_title = false, big_title = true, home_link = true) => {
     }
     // 置底
     for (let ele of document.querySelectorAll('code>textarea')) { art.unfold_code(ele) }
-
-    {
-        text.addEventListener('click', async (event) => {
-            event.preventDefault()
-            let target = event.target
-            let href = target.href || target.getAttribute('href')
-            if (href) {
-                window.open(href, '_blank')
-            }
-            else if (window.frameElement) {
-                if (aim_url) {
-                    window.open(aim_url, '_blank')
-                }
-                else {
-                    window.open(document.URL, '_blank')
-                }
-            }
-        })
-    }
 }
 
 {
     document.documentElement.setAttribute('screen_type', 'y')  // 检测失败时按竖屏处理
-    const iframe = window.frameElement
+    let iframe = window.frameElement
     if (iframe) {
-        const resizeObserver = new ResizeObserver(entries => {
+        let resizeObserver = new ResizeObserver(entries => {
             iframe.style.height = `${entries[0].contentRect.height}px`
         })
         resizeObserver.observe(document.documentElement)
