@@ -1,7 +1,3 @@
-'''
-运行此脚本，将自动为指定的本地文件生成哈希值，并将生成的哈希值保存到 `许灿标本地文件哈希值.yaml` 中。
-'''
-
 import hashlib, datetime, platform
 from pathlib import Path
 from os.path import abspath
@@ -32,7 +28,7 @@ hashes = loop(local_files_dir)[1]
 
 environment_info = dict(
     操作系统 = platform.system(),
-    系统版本 = platform.release(),
+    操作系统版本 = platform.release(),
     Python版本 = platform.python_version(),
     生成日期_UTC = datetime.datetime.now(datetime.timezone.utc).isoformat()[:10],
 )
